Changelog
=========

1.0 (2018-02-14)
----------------

- Moved to `tooltipster` 4.2.6.
  [gbastien]
- Added `tooltipster_helper` method to ease use of `tooltipster`.
  [gbastien]


0.1 (2016-09-22)
----------------

- Initial release.
  [gbastien]

